@@ -346,7 +346,7 @@ class Slice(Op):
     def __repr__(self):
         def s(a):
             return str(a) if a is not None else ''
-        if not self.args:
+        if not self.args or self.args == (None, None, None):
             return '[]'
         start, stop, step = self.args
         m = [s(start), s(stop)]
@@ -374,8 +374,6 @@ class Slice(Op):
     def match(self, op, specials=False):
         if not isinstance(op, Slice):
             return None
-        if not self.op.matchable(op.op, specials):
-            return None
         return Match(op.slice) if self.slice == op.slice else None
 
     def update(self, node, key, val):
